# RawToken

Raw token

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token** | **str** | token string | 
**refresh_token** | **str** | A refresh token specific to token.  | [optional] 
**session** | **str** | Unique identifier | [optional] [readonly] 
**time_validity** | [**TimeValidity**](TimeValidity.md) |  | [optional] 
**user** | [**User**](User.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


